etwist/server.py
changeset 2476 1294a6bdf3bf
parent 2181 94ca417b9b07
child 2654 6512522860aa
--- a/etwist/server.py	Fri Jul 24 13:50:59 2009 +0200
+++ b/etwist/server.py	Fri Jul 24 14:33:37 2009 +0200
@@ -1,4 +1,4 @@
-"""twisted server for CubicWeb web applications
+"""twisted server for CubicWeb web instances
 
 :organization: Logilab
 :copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
@@ -271,9 +271,9 @@
 
 # This part gets run when you run this file via: "twistd -noy demo.py"
 def main(appid, cfgname):
     """Starts an cubicweb  twisted server for an application
 
-    appid: application's identifier
+    appid: instance's identifier
     cfgname: name of the configuration to use (twisted or all-in-one)
     """
     from cubicweb.cwconfig import CubicWebConfiguration
@@ -271,9 +271,9 @@
 # This part gets run when you run this file via: "twistd -noy demo.py"
 def main(appid, cfgname):
-    """Starts an cubicweb  twisted server for an application
+    """Starts an cubicweb  twisted server for an instance
 